<?php
declare(strict_types=1);


/**
 * Nextcloud - Social Support
 *
 * This file is licensed under the Affero General Public License version 3 or
 * later. See the COPYING file.
 *
 * @author Maxence Lange <maxence@artificial-owl.com>
 * @copyright 2018, Maxence Lange <maxence@artificial-owl.com>
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


namespace OCA\Social\Migration;


use Closure;
use OCA\Social\Db\CoreRequestBuilder;
use OCP\DB\ISchemaWrapper;
use OCP\Migration\IOutput;
use OCP\Migration\SimpleMigrationStep;


/**
 * Class Version0001Date20181208185242
 *
 * @package OCA\Social\Migration
 */
class Version0001Date20181208185242 extends SimpleMigrationStep {


	/**
	 * @param IOutput $output
	 * @param Closure $schemaClosure The `\Closure` returns a `ISchemaWrapper`
	 * @param array $options
	 *
	 * @return ISchemaWrapper
	 * @throws \Doctrine\DBAL\Schema\SchemaException
	 */
	public function changeSchema(IOutput $output, Closure $schemaClosure, array $options
	): ISchemaWrapper {
		/** @var ISchemaWrapper $schema */
		$schema = $schemaClosure();

		$table = $schema->getTable(CoreRequestBuilder::TABLE_CACHE_ACTORS);
		$table->changeColumn(
			'source', [
						'notnull' => true,
						'length'  => CoreRequestBuilder::SOURCE_LENGTH,
					]
		);

		$table = $schema->getTable(CoreRequestBuilder::TABLE_SERVER_NOTES);
		$table->changeColumn(
			'source', [
						'notnull' => true,
						'length'  => CoreRequestBuilder::SOURCE_LENGTH,
					]
		);

		$table = $schema->getTable(CoreRequestBuilder::TABLE_REQUEST_QUEUE);
		$table->changeColumn(
			'activity', [
						  'notnull' => true,
						  'length'  => CoreRequestBuilder::SOURCE_LENGTH,
					  ]
		);

		return $schema;
	}
}
